// Copyright (c) 2017, 2021, Oracle and/or its affiliates. All rights reserved.

variable "tenancy_ocid" {
}

variable "user_ocid" {
}

variable "fingerprint" {
}

variable "private_key_path" {
}

variable "region" {
}

variable "compartment_ocid" {
}

variable "host_scan_instance_ocid" {

}

variable "container_repo_name" {

}

provider "oci" {
  tenancy_ocid     = var.tenancy_ocid
  user_ocid        = var.user_ocid
  fingerprint      = var.fingerprint
  private_key_path = var.private_key_path
  region           = var.region
}

resource "oci_vulnerability_scanning_host_scan_recipe" "test_host_scan_recipe" {
    #Required
    agent_settings {
      #Required
      scan_level = "NONE"

      #Optional
      agent_configuration {
        #Required
        vendor = "OCI"

        #Optional
        cis_benchmark_settings {

          #Optional
          scan_level = "NONE"
        }
      }
    }
    compartment_id = var.compartment_ocid
    port_settings {
      #Required
      scan_level = "NONE"
    }
    schedule {
      #Required
      type = "DAILY"

      #Optional
      day_of_week = "SUNDAY"
    }

    #Optional
    display_name = "TestHostScanRecipe"
}

resource "oci_vulnerability_scanning_host_scan_target" "test_host_scan_target" {
  #Required
  compartment_id = var.compartment_ocid
  host_scan_recipe_id = oci_vulnerability_scanning_host_scan_recipe.test_host_scan_recipe.id
  target_compartment_id = var.compartment_ocid

  #Optional
  description = "Test target example"
  display_name = "TestHostScanTarget"
  freeform_tags = {"bar-key"= "value"}
  instance_ids = [var.host_scan_instance_ocid]
}

resource "oci_vulnerability_scanning_container_scan_target" "test_container_scan_target" {
  #Required
  compartment_id = var.compartment_ocid
  container_scan_recipe_id = oci_vulnerability_scanning_container_scan_recipe.test_container_scan_recipe.id
  target_registry {
    #Required
    compartment_id = var.compartment_ocid
    type = "OCIR"

    #Optional
    repositories = [var.container_repo_name]
    url = "https://us-ashburn-1.ocir.io/"
  }

  #Optional
  description = "Container scan target example"
  display_name = "TestContainerScanTarget"
}

resource "oci_vulnerability_scanning_container_scan_recipe" "test_container_scan_recipe" {
  #Required
  compartment_id = var.compartment_ocid
  scan_settings {
    #Required
    scan_level = "NONE"
  }

  #Optional
  defined_tags = {"foo-namespace.bar-key"= "value"}
  display_name = "TestContainerScanRecipe"
  freeform_tags = {"bar-key"= "value"}
}